summaryrefslogtreecommitdiffstats
path: root/test/Modules/macros.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/Modules/macros.c')
-rw-r--r--test/Modules/macros.c25
1 files changed, 7 insertions, 18 deletions
diff --git a/test/Modules/macros.c b/test/Modules/macros.c
index 899c19b..83e1c66 100644
--- a/test/Modules/macros.c
+++ b/test/Modules/macros.c
@@ -1,20 +1,10 @@
-// RUN: %clang_cc1 -emit-module -o %t/macros.pcm -DMODULE %s
-// RUN: %clang_cc1 -verify -fmodule-cache-path %t -fdisable-module-hash %s
-// RUN: %clang_cc1 -E -fmodule-cache-path %t -fdisable-module-hash %s | FileCheck -check-prefix CHECK-PREPROCESSED %s
+// RUN: rm -rf %t
+// RUN: %clang_cc1 -fmodules -x objective-c -emit-module -fmodule-cache-path %t -fmodule-name=macros %S/Inputs/module.map
+// RUN: %clang_cc1 -fmodules -x objective-c -verify -fmodule-cache-path %t %s
+// RUN: %clang_cc1 -E -fmodules -x objective-c -fmodule-cache-path %t %s | FileCheck -check-prefix CHECK-PREPROCESSED %s
+// FIXME: When we have a syntax for modules in C, use that.
-#if defined(MODULE)
-#define INTEGER(X) int
-#define FLOAT float
-#define DOUBLE double
-
-#__export_macro__ INTEGER
-#__export_macro__ DOUBLE
-
-int (INTEGER);
-
-#else
-
-__import_module__ macros;
+@__experimental_modules_import macros;
#ifndef INTEGER
# error INTEGER macro should be visible
@@ -32,10 +22,9 @@ __import_module__ macros;
double d;
DOUBLE *dp = &d;
-#__export_macro__ WIBBLE // expected-error{{no macro named 'WIBBLE' to export}}
+#__public_macro WIBBLE // expected-error{{no macro named 'WIBBLE'}}
void f() {
// CHECK-PREPROCESSED: int i = INTEGER;
int i = INTEGER; // the value was exported, the macro was not.
}
-#endif
OpenPOWER on IntegriCloud